inline_simple_tables.pdf

## Metadata

Title | inline_simple_tables.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\inline_simple_tables.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403061139+01'00'
PDF Metadata: modDate | D:20230403061139+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

No images

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 284.3299865722656
y1 |  | 628.707275390625
y0 |  | 508.7972717285156
x0 |  | 72.02400207519531

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 524.2659912109375
y1 |  | 440.1572570800781
y0 |  | 333.697265625
x0 |  | 315.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 511.6779479980469
y1 |  | 125.7072525024414
y0 |  | 73.26725006103516
x0 |  | 315.42999267578125

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 447.3399963378906
y1 |  | 502.6772766113281
y0 |  | 457.3172607421875
x0 |  | 438.70001220703125

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 204.64999389648438
y1 |  | 460.7972717285156
y0 |  | 401.75726318359375
x0 |  | 169.82000732421875

Path: | content.0.[22,22].bbox
Type: | addition

Key | Old | New
x1 |  | 447.3399963378906
y1 |  | 535.1973266601562
y0 |  | 523.1973266601562
x0 |  | 438.70001220703125

Path: | content.0.[23,23].bbox
Type: | addition

Key | Old | New
x1 |  | 512.6199951171875
y1 |  | 535.1973266601562
y0 |  | 523.1973266601562
x0 |  | 480.4599914550781

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 449.9800109863281
y1 |  | 298.7772521972656
y0 |  | 141.3072967529297
x0 |  | 369.42999267578125

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 456.13397216796875
y1 |  | 280.52996826171875
y0 |  | 258.489990234375
x0 |  | 406.8299865722656

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 513.7000122070312
y1 |  | 485.75726318359375
y0 |  | 457.3172607421875
x0 |  | 479.5

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 513.9400024414062
y1 |  | 516.2373046875
y0 |  | 490.6772766113281
x0 |  | 479.1400146484375

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

1 2 3

Lorem Upsun Batan Autem

4

Golde

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

1 | Lorem
2 | Upsun
3 | Batan
4 | Golde
5 | Lorem
6 | Upsun
7 | Batan
8 | Golde

Autem

Autem

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

1 2 3

Lorem Upsun

1 2 3

Lorem Upsun

Batan Autem

Batan Autem

4

Golde

4

Golde

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

1 2 3

Lorem Upsun Batan Autem

4

Golde

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

1 | Lorem
2 | Upsun
3 | Batan
4 | Golde
5 | Lorem
6 | Upsun
7 | Batan
8 | Golde

Autem

Autem

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

1 2 3

Lorem Upsun

1 2 3

Lorem Upsun

Batan Autem

Batan Autem

4

Golde

4

Golde

Parent File Contents